@@ -32,7 +32,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #define ID_WRITE_DIRECT
 /* define USE_FLUSH_NEXT */
@@ -41,9 +41,22 @@
 static int flush_next = 0;
 #endif
 
+/*
+** Inspiration : http://sourcefrog.net/weblog/software/languages/C/unused.html
+*/
+#ifdef UNUSED
+#elif defined (__GNUC__)
+#       define UNUSED(x) UNUSED_ ## x __attribute__ ((unused))
+#elif defined (__LCLINT__)
+#       define UNUSED(x) /*@unused@*/ x
+#else
+#       define UNUSED(x) x
+#endif
+
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * UNUSED(oggz), oggz_packet * zp, long serialno, void * user_data)
 {
+  ogg_packet * op = &zp->op;
   OGGZ * writer = (OGGZ *)user_data;
   int flush;
   int ret;
