@@ -40,7 +40,19 @@
 #  define PRId64 "I64d"
 #endif
  
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
+
+/*
+** Inspiration : http://sourcefrog.net/weblog/software/languages/C/unused.html
+*/
+#ifdef UNUSED
+#elif defined (__GNUC__)
+#       define UNUSED(x) UNUSED_ ## x __attribute__ ((unused))
+#elif defined (__LCLINT__)
+#       define UNUSED(x) /*@unused@*/ x
+#else
+#       define UNUSED(x) x
+#endif
 
 static int got_an_eos = 0;
 
@@ -60,8 +72,9 @@ print_granulepos (ogg_int64_t granulepos, int granuleshift)
 
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * UNUSED(user_data))
 {
+  ogg_packet * op = &zp->op;
   int granuleshift;
 
   granuleshift = oggz_get_granuleshift (oggz, serialno);
