@@ -32,6 +32,7 @@
 
 #include "config.h"
 
+#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include "oggz/oggz.h"
@@ -42,10 +43,22 @@
 #  define PRId64 "I64d"
 #endif
 
+/*
+** Inspiration : http://sourcefrog.net/weblog/software/languages/C/unused.html
+*/
+#ifdef UNUSED
+#elif defined (__GNUC__)
+#       define UNUSED(x) UNUSED_ ## x __attribute__ ((unused))
+#elif defined (__LCLINT__)
+#       define UNUSED(x) /*@unused@*/ x
+#else
+#       define UNUSED(x) x
+#endif
+
 static int got_an_eos = 0;
 
 static int
-read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
+read_packet (OGGZ * UNUSED(oggz), oggz_packet * zp, long serialno, void * UNUSED(user_data))
 {
   ogg_packet * op = &zp->op;
 
@@ -73,7 +86,7 @@ my_io_read (void * user_handle, void * buf, size_t n)
 {
   FILE * f = (FILE *)user_handle;
 
-  return fread (buf, 1, n, f);
+  return read (fileno(f), buf, n);
 }
 
 static int
