@@ -225,7 +225,7 @@ oggz_comment_cmp (const OggzComment * comment1, const OggzComment * comment2, co
 }
 
 static int
-_oggz_comment_set_vendor (OGGZ * oggz, long serialno,
+oggz_comment_set_vendor_ (OGGZ * oggz, long serialno,
 			  const char * vendor_string)
 {
   oggz_stream_t * stream;
@@ -273,7 +273,7 @@ oggz_comment_set_vendor (OGGZ * oggz, long serialno, const char * vendor_string)
   if (oggz->flags & OGGZ_WRITE) {
     if (OGGZ_CONFIG_WRITE) {
 
-      return _oggz_comment_set_vendor (oggz, serialno, vendor_string);
+      return oggz_comment_set_vendor_ (oggz, serialno, vendor_string);
 
     } else {
       return OGGZ_ERR_DISABLED;
@@ -364,7 +364,7 @@ oggz_comment_next_byname (OGGZ * oggz, long serialno,
 }
 
 static OggzComment *
-_oggz_comment_add_byname (oggz_stream_t * stream, const char * name, const char * value)
+oggz_comment_add_byname_ (oggz_stream_t * stream, const char * name, const char * value)
 {
   OggzComment * comment, * new_comment;
   int i;
@@ -409,7 +409,7 @@ oggz_comment_add (OGGZ * oggz, long serialno, const OggzComment * comment)
       if (!oggz_comment_validate_byname (comment->name))
         return OGGZ_ERR_COMMENT_INVALID;
 
-      if (_oggz_comment_add_byname (stream, comment->name, comment->value) == NULL)
+      if (oggz_comment_add_byname_ (stream, comment->name, comment->value) == NULL)
         return OGGZ_ERR_OUT_OF_MEMORY;
 
       return 0;
@@ -442,7 +442,7 @@ oggz_comment_add_byname (OGGZ * oggz, long serialno,
       if (!oggz_comment_validate_byname (name))
         return OGGZ_ERR_COMMENT_INVALID;
 
-      if (_oggz_comment_add_byname (stream, name, value) == NULL)
+      if (oggz_comment_add_byname_ (stream, name, value) == NULL)
         return OGGZ_ERR_OUT_OF_MEMORY;
 
       return 0;
@@ -597,7 +597,7 @@ oggz_comments_decode (OGGZ * oggz, long serialno,
      if ((nvalue = oggz_strdup_len (c, len)) == NULL)
        return OGGZ_ERR_OUT_OF_MEMORY;
 
-     if (_oggz_comment_set_vendor (oggz, serialno, nvalue) == OGGZ_ERR_OUT_OF_MEMORY) {
+     if (oggz_comment_set_vendor_ (oggz, serialno, nvalue) == OGGZ_ERR_OUT_OF_MEMORY) {
        oggz_free (nvalue);
        return OGGZ_ERR_OUT_OF_MEMORY;
      }
@@ -644,7 +644,7 @@ oggz_comments_decode (OGGZ * oggz, long serialno,
          printf ("oggz_comments_decode: [%d] %s -> %s (length %d)\n",
          i, name, nvalue, n);
 #endif
-         if (_oggz_comment_add_byname (stream, name, nvalue) == NULL) {
+         if (oggz_comment_add_byname_ (stream, name, nvalue) == NULL) {
            oggz_free (nvalue);
            return OGGZ_ERR_OUT_OF_MEMORY;
 	 }
@@ -664,7 +664,7 @@ oggz_comments_decode (OGGZ * oggz, long serialno,
          i, nvalue, len);
 #endif
 
-         if (_oggz_comment_add_byname (stream, nvalue, NULL) == NULL) {
+         if (oggz_comment_add_byname_ (stream, nvalue, NULL) == NULL) {
            oggz_free (nvalue);
            return OGGZ_ERR_OUT_OF_MEMORY;
 	 }
