@@ -30,8 +30,8 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef __OGGZ_MACROS_H__
-#define __OGGZ_MACROS_H__
+#ifndef OGGZ_MACROS_HEADER
+#define OGGZ_MACROS_HEADER
 
 #include <stdlib.h>
 #include <ogg/ogg.h>
@@ -47,4 +47,22 @@
 #undef MAX
 #define MAX(a,b) ((a)>(b)?(a):(b))
 
-#endif /* __OGGZ_MACROS_H__ */
+/*
+** Inspiration : http://sourcefrog.net/weblog/software/languages/C/unused.html
+*/
+#ifdef UNUSED
+#elif defined (__GNUC__)
+#       define UNUSED(x) UNUSED_ ## x __attribute__ ((unused))
+#elif defined (__LCLINT__)
+#       define UNUSED(x) /*@unused@*/ x
+#else
+#       define UNUSED(x) x
+#endif
+
+#ifdef __GNUC__
+#       define WARN_UNUSED      __attribute__ ((warn_unused_result))
+#else
+#       define WARN_UNUSED
+#endif
+
+#endif /* OGGZ_MACROS_HEADER */
