@@ -30,8 +30,8 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef __OGGZ_PRIVATE_H__
-#define __OGGZ_PRIVATE_H__
+#ifndef OGGZ_PRIVATE_HEADER
+#define OGGZ_PRIVATE_HEADER
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -48,11 +48,11 @@
 
 #define OGGZ_AUTO_MULT 1000Ull
 
-typedef struct _OGGZ OGGZ;
-typedef struct _OggzComment OggzComment;
-typedef struct _OggzIO OggzIO;
-typedef struct _OggzReader OggzReader;
-typedef struct _OggzWriter OggzWriter;
+typedef struct OGGZ_ OGGZ;
+typedef struct OggzComment_ OggzComment;
+typedef struct OggzIO_ OggzIO;
+typedef struct OggzReader_ OggzReader;
+typedef struct OggzWriter_ OggzWriter;
 
 
 typedef int (*OggzReadPacket) (OGGZ * oggz, oggz_packet * op, long serialno,
@@ -79,7 +79,7 @@ typedef int (*OggzIOSeek) (void * user_handle, long offset, int whence);
 typedef long (*OggzIOTell) (void * user_handle);
 typedef int (*OggzIOFlush) (void * user_handle);
 
-struct _oggz_stream_t {
+struct oggz_stream_t_ {
   ogg_stream_state ogg_stream;
 
   /** STATIC INFO */
@@ -126,7 +126,7 @@ struct _oggz_stream_t {
   ogg_packet * last_packet;
 };
 
-struct _OggzReader {
+struct OggzReader_ {
   ogg_sync_state ogg_sync;
 
   /* XXX: these two can prolly be removed again :) */
@@ -171,7 +171,7 @@ enum oggz_writer_state {
   OGGZ_WRITING_PAGES = 1
 };
 
-struct _OggzWriter {
+struct OggzWriter_ {
   oggz_writer_packet_t * next_zpacket; /* stashed in case of FLUSH_BEFORE */
   OggzVector * packet_queue;
 
@@ -202,7 +202,7 @@ struct _OggzWriter {
 
 };
 
-struct _OggzIO {
+struct OggzIO_ {
   OggzIORead read;
   void * read_user_handle;
 
@@ -219,7 +219,7 @@ struct _OggzIO {
   void * flush_user_handle;
 };
 
-struct _OggzComment {
+struct OggzComment_ {
   /** The name of the comment, eg. "AUTHOR" */
   char * name;
 
@@ -227,7 +227,7 @@ struct _OggzComment {
   char * value;
 };
 
-struct _OGGZ {
+struct OGGZ_ {
   int flags;
   FILE * file;
   OggzIO * io;
@@ -333,4 +333,4 @@ int oggz_io_flush (OGGZ * oggz);
 OggzDListIterResponse oggz_read_free_pbuffers(void *elem);
 #endif /* OGGZ_CONFIG_READ */
 
-#endif /* __OGGZ_PRIVATE_H__ */
+#endif /* OGGZ_PRIVATE_HEADER */
