@@ -194,6 +194,7 @@ oggz_read_get_next_page (OGGZ * oggz, ogg_page * og)
           oggz->offset, reader->current_page_bytes);
 #endif
   oggz->offset += reader->current_page_bytes;
+  reader->current_page_bytes = 0;
 
   do {
     more = ogg_sync_pageseek (&reader->ogg_sync, og);
@@ -394,7 +395,7 @@ oggz_read_sync (OGGZ * oggz)
           /* We can't tolerate holes in headers, so bail out. NB. as stream->packetno
            * has not yet been incremented, the current value refers to how many packets
            * have been processed prior to this one. */
-          if (stream->packetno < 2) return OGGZ_ERR_HOLE_IN_DATA;
+          if (stream->packetno < stream->numheaders - 1) return OGGZ_ERR_HOLE_IN_DATA;
 
           /* Holes in content occur in some files and pretty much don't matter,
            * so we silently swallow the notification and reget the packet. */
@@ -453,7 +454,9 @@ oggz_read_sync (OGGZ * oggz)
           }
 
           if (stream->packetno == 1) {
-            oggz_auto_read_comments (oggz, stream, serialno, op);
+            if (-1 == oggz_auto_read_comments (oggz, stream, serialno, op)) {
+	      return OGGZ_ERR_COMMENT_INVALID;
+	    }
           }
           
           /* Fill in position information. */
