@@ -900,7 +900,7 @@ oggz_seek_packets (OGGZ * UNUSED(oggz), long UNUSED(serialno), long UNUSED(packe
   return -1;
 }
 
-#else
+#else /* ! OGGZ_CONFIG_READ */
 
 #include <ogg/ogg.h>
 #include "oggz_private.h"
@@ -929,4 +929,4 @@ oggz_seek_packets (OGGZ * oggz, long serialno, long packets, int whence)
   return OGGZ_ERR_DISABLED;
 }
 
-#endif
+#endif /* ! OGGZ_CONFIG_READ */
