@@ -46,7 +46,7 @@ static long serialno;
 static int read_called = 0;
 
 static int
-hungry (OGGZ * oggz, int empty, void * user_data)
+hungry (OGGZ * oggz, int UNUSED(empty), void * UNUSED(user_data))
 {
   unsigned char buf[1];
   ogg_packet op;
@@ -77,7 +77,7 @@ hungry (OGGZ * oggz, int empty, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
+read_packet (OGGZ * NDUNUSED(oggz), oggz_packet * zp, long UNUSED(serialno), void * UNUSED(user_data))
 {
   ogg_packet * op = &zp->op;
   static int iter = 0;
@@ -144,7 +144,7 @@ my_io_read (void * user_handle, void * buf, size_t n)
 }
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   OGGZ * reader, * writer;
   unsigned char data_buf[DATA_BUF_LEN];
