@@ -41,7 +41,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #include "oggz_tests.h"
 
@@ -70,7 +70,7 @@ static unsigned char vorbis_bos[] = {1, 'v', 'o', 'r', 'b', 'i', 's',
 		     
 
 static int
-hungry (OGGZ * oggz, int empty, void * user_data)
+hungry (OGGZ * oggz, int UNUSED(empty), void * UNUSED(user_data))
 {
   unsigned char buf[1];
   ogg_packet op;
@@ -106,8 +106,9 @@ hungry (OGGZ * oggz, int empty, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * NDUNUSED(oggz), oggz_packet * zp, long UNUSED(serialno), void * UNUSED(user_data))
 {
+  ogg_packet * op = &zp->op;
   static int iter = 0;
   static long b_o_s = 1;
   static long e_o_s = 0;
@@ -177,7 +178,7 @@ my_io_read (void * user_handle, void * buf, size_t n)
 }
 
 static int
-my_io_seek (void * user_handle, long offset, int whence)
+my_io_seek (void * UNUSED(user_handle), long offset, int whence)
 {
   switch (whence) {
   case SEEK_SET:
@@ -197,13 +198,13 @@ my_io_seek (void * user_handle, long offset, int whence)
 }
 
 static long
-my_io_tell (void * user_handle)
+my_io_tell (void * UNUSED(user_handle))
 {
   return my_offset;
 }
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   OGGZ * reader, * writer;
   unsigned char data_buf[DATA_BUF_LEN];
