@@ -50,7 +50,7 @@ static int offset_end = 0;
 static int my_offset = 0;
 
 static int
-hungry (OGGZ * oggz, int empty, void * user_data)
+hungry (OGGZ * oggz, int UNUSED(empty), void * UNUSED(user_data))
 {
   unsigned char buf[1];
   ogg_packet op;
@@ -81,7 +81,7 @@ hungry (OGGZ * oggz, int empty, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
+read_packet (OGGZ * NDUNUSED(oggz), oggz_packet * zp, long UNUSED(serialno), void * UNUSED(user_data))
 {
   ogg_packet * op = &zp->op;
   static int iter = 0;
@@ -153,7 +153,7 @@ my_io_read (void * user_handle, void * buf, size_t n)
 }
 
 static int
-my_io_seek (void * user_handle, long offset, int whence)
+my_io_seek (void * UNUSED(user_handle), long offset, int whence)
 {
   switch (whence) {
   case SEEK_SET:
@@ -173,13 +173,13 @@ my_io_seek (void * user_handle, long offset, int whence)
 }
 
 static long
-my_io_tell (void * user_handle)
+my_io_tell (void * UNUSED(user_handle))
 {
   return my_offset;
 }
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   OGGZ * reader, * writer;
   unsigned char data_buf[DATA_BUF_LEN];
