@@ -38,7 +38,7 @@ static long serialno;
 static int guard = 1; /* bad initialization value */
 
 static int
-hungry (OGGZ * oggz, int empty, void * user_data)
+hungry (OGGZ * oggz, int UNUSED(empty), void * UNUSED(user_data))
 {
   unsigned char buf[1];
   ogg_packet op;
@@ -61,7 +61,7 @@ hungry (OGGZ * oggz, int empty, void * user_data)
 }
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   OGGZ * oggz;
   unsigned char buf[1];
