@@ -37,7 +37,7 @@ static const long good_serialno = 0x77L;
 static const long bad_serialno = (long)0x777777777777LL;
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   OGGZ * oggz;
   unsigned char buf[1];
