@@ -8,7 +8,7 @@
 #include "httpdate.h"
 
 int
-main (int argc, char * argv[])
+main (int UNUSED(argc), char * UNUSED(argv[]))
 {
   char * d_in = "Mon, 06 Feb 2006 11:20:01 GMT";
   char d_out[30];
