@@ -57,7 +57,7 @@
  * OCTrackState
  */
 
-typedef struct _OCTrackState {
+typedef struct {
   /* Skeleton track info (fisbone) */
   fisbone_packet fisbone;
 
@@ -145,7 +145,7 @@ state_clear (OCState * state)
  */
 
 static ogg_page *
-_ogg_page_copy (const ogg_page * og)
+ogg_page_copy_ (const ogg_page * og)
 {
   ogg_page * new_og;
 
@@ -171,7 +171,7 @@ _ogg_page_copy (const ogg_page * og)
 }
 
 static void
-_ogg_page_free (const ogg_page * og)
+ogg_page_free_ (const ogg_page * og)
 {
   if (og == NULL) return;
 
@@ -181,7 +181,7 @@ _ogg_page_free (const ogg_page * og)
 }
 
 static void
-_ogg_page_set_eos (const ogg_page * og)
+ogg_page_set_eos_ (const ogg_page * og)
 {
   if (og == NULL) return;
 
@@ -207,7 +207,7 @@ fwrite_ogg_page (OCState * state, const ogg_page * og)
  * OCPageAccum
  */
 
-typedef struct _OCPageAccum {
+typedef struct {
   ogg_page * og;
   double time;
 } OCPageAccum;
@@ -220,7 +220,7 @@ page_accum_new (const ogg_page * og, double time)
   if ((pa = malloc(sizeof (*pa))) == NULL)
     return NULL;
 
-  if ((pa->og = _ogg_page_copy (og)) == NULL) {
+  if ((pa->og = ogg_page_copy_ (og)) == NULL) {
     free (pa);
     return NULL;
   }
@@ -235,7 +235,7 @@ page_accum_delete (OCPageAccum * pa)
 {
   if (pa == NULL) return;
 
-  _ogg_page_free (pa->og);
+  ogg_page_free_ (pa->og);
   free (pa);
 }
 
@@ -628,7 +628,7 @@ read_plain (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
     fwrite_ogg_page (state, og);
   } else if (state->end != -1.0 && page_time > state->end) {
     /* This is the first page past the end time; set EOS */
-    _ogg_page_set_eos (og);
+    ogg_page_set_eos_ (og);
     fwrite_ogg_page (state, og);
 
     /* Stop handling this track */
