@@ -29,8 +29,8 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef __OGGZ_CHOP_H__
-#define __OGGZ_CHOP_H__
+#ifndef OGGZ_CHOP_HEADER
+#define OGGZ_CHOP_HEADER
 
 #include <oggz/oggz.h>
 
@@ -46,7 +46,7 @@ typedef enum {
   OC_GLUE_DONE /* Written accum pages, copy remaining data to end */
 } OCStatus;
 
-typedef struct _OCState {
+typedef struct {
   OCStatus status;
 
   char * infilename;
@@ -73,4 +73,4 @@ typedef struct _OCState {
 
 int chop (OCState * state);
 
-#endif /* __OGGZ_CHOP_H__ */
+#endif /* OGGZ_CHOP_HEADER */
