@@ -49,7 +49,7 @@
 #include <getopt.h>
 #include <errno.h>
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 #include "oggz_tools.h"
 
 /*#define DEBUG*/
@@ -89,8 +89,8 @@ usage (char * progname)
   printf ("  -n, --new              Only dump the first packet of each logical bitstream\n");
   printf ("  -c content-type, --content-type content-type\n");
   printf ("                         Dump only the logical bitstreams for a specified\n");
-  printf ("                         content-type. The following codecs are currently\n");
-  printf ("                         detected: theora, vorbis, speex, cmml, kate\n");
+  printf ("                         content-type. Run oggz-known-codecs for a list of\n");
+  printf ("                         codec names which can be detected by this version of oggz.\n");
   printf ("  -s serialno, --serialno serialno\n");
   printf ("                         Dump only the logical bitstream with specified serialno\n");
   printf ("  -O, --hide-offset      Hide the byte offset of each packet\n");
@@ -254,9 +254,10 @@ bin_dump (unsigned char * buf, long n, int dump_char)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
 {
   ODData * oddata = (ODData *) user_data;
+  ogg_packet * op = &zp->op;
   ogg_int64_t units;
   double time_offset;
   ogg_int64_t calced_gp = oggz_tell_granulepos (oggz);
@@ -342,10 +343,12 @@ filter_page (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
 }
 
 static int
-read_new_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_new_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
 {
+  ogg_packet * op = &zp->op;
+
   if (op->b_o_s) {
-    read_packet (oggz, op, serialno, user_data);
+    read_packet (oggz, zp, serialno, user_data);
     return OGGZ_CONTINUE;
   } else {
     return OGGZ_STOP_OK;
@@ -361,7 +364,7 @@ revert_packet (OGGZ * oggz, ogg_packet * op, long serialno, int flush)
 
 #ifdef DEBUG
   printf ("feeding packet (%010lu) %ld bytes %s, %s\n",
-          current_serialno, op->bytes,
+          serialno, op->bytes,
           op->b_o_s ? "bos" : "not bos",
           op->e_o_s ? "eos" : "not eos");
 #endif
@@ -403,6 +406,17 @@ revert_file (char * infilename)
     infile = fopen (infilename, "rb");
   }
 
+  if (infile == NULL) {
+    if (errno == 0) {
+      fprintf (stderr, "%s: %s: error opening input file\n",
+               progname, infilename);
+    } else {
+      fprintf (stderr, "%s: %s: %s\n",
+               progname, infilename, strerror (errno));
+    }
+    exit(1);
+  }
+
   oggz = oggz_new (OGGZ_WRITE|OGGZ_NONSTRICT|OGGZ_AUTO);
   if (oggz == NULL)
     exit_out_of_memory();
@@ -416,11 +430,17 @@ revert_file (char * infilename)
 
     is_packetinfo = 0;
     if (sscanf (&line[line_offset], "%x: serialno %ld, granulepos %" PRId64 ", packetno %" PRId64 "%n",
+		&offset, &serialno, &granulepos, &packetno,
+		&line_offset) >= 4 ||
+        sscanf (&line[line_offset], "%x: serialno %ld, calc. gpos %" PRId64 ", packetno %" PRId64 "%n",
 		&offset, &serialno, &granulepos, &packetno,
 		&line_offset) >= 4) {
       is_packetinfo = 1;
     } else {
-      if (sscanf (&line[line_offset], "%x: serialno %ld, granulepos %" PRId64 "%" PRId64 ", packetno %" PRId64 "%n",
+      if (sscanf (&line[line_offset], "%x: serialno %ld, granulepos %" PRId64 "|%" PRId64 ", packetno %" PRId64 "%n",
+		  &offset, &serialno, &iframe, &pframe, &packetno,
+		  &line_offset) >= 5 ||
+          sscanf (&line[line_offset], "%x: serialno %ld, calc. gpos %" PRId64 "|%" PRId64 ", packetno %" PRId64 "%n",
 		  &offset, &serialno, &iframe, &pframe, &packetno,
 		  &line_offset) >= 5) {
 	int granuleshift = oggz_get_granuleshift (oggz, serialno);
@@ -709,9 +729,15 @@ main (int argc, char ** argv)
 
  exit_ok:
   oddata_delete (oddata);
+  if (outfilename != NULL) {
+    fclose (outfile);
+  }
   exit (0);
 
  exit_err:
   oddata_delete (oddata);
+  if (outfilename != NULL) {
+    fclose (outfile);
+  }
   exit (1);
 }
