@@ -36,13 +36,14 @@
 #include <string.h>
 
 #include "oggz/oggz.h"
+#include "oggz_macros.h"
 
 /* #define DEBUG */
 
 typedef int (*qsort_func) (const void * p1, const void * p2);
 
 int
-usage (char * progname)
+usage (char * UNUSED(progname))
 {
   printf ("Usage: oggz-known-codecs [options]\n\n");
 
