@@ -79,29 +79,25 @@ checked_fwrite (const void *data, size_t size, size_t count, FILE *stream)
   }
 }
 
-typedef struct _OSData OSData;
-typedef struct _OSInput OSInput;
-typedef struct _OSITrack OSITrack;
-
-struct _OSData {
+typedef struct {
   char * infilename;
   OggzTable * inputs;
   int verbose;
-};
+} OSData;
 
-struct _OSInput {
+typedef struct {
   OSData * osdata;
   OGGZ * reader;
   long serialno;
   const ogg_page * og;
-};
+} OSInput;
 
-struct _OSITrack {
+typedef struct {
   long output_serialno;
-};
+} OSITrack;
 
 static ogg_page *
-_ogg_page_copy (const ogg_page * og)
+ogg_page_copy_ (const ogg_page * og)
 {
   ogg_page * new_og;
 
@@ -129,7 +125,7 @@ _ogg_page_copy (const ogg_page * og)
 }
 
 static int
-_ogg_page_free (const ogg_page * og)
+ogg_page_free_ (const ogg_page * og)
 {
   free (og->header);
   free (og->body);
@@ -189,7 +185,7 @@ read_page (OGGZ * UNUSED(oggz), const ogg_page * og, long serialno, void * user_
    * otherwise continue scanning the file */
   if (serialno == input->serialno) {
     ogg_page *iog;
-    iog = _ogg_page_copy (og);
+    iog = ogg_page_copy_ (og);
     if (iog == NULL) return OGGZ_STOP_ERR;
 
     /* If this page's granulepos should be -1 but isn't then fix that before
@@ -359,7 +355,7 @@ oggz_sort (OSData * osdata, FILE * outfile)
       checked_fwrite (og->header, 1, og->header_len, outfile);
       checked_fwrite (og->body, 1, og->body_len, outfile);
 
-      _ogg_page_free (og);
+      ogg_page_free_ (og);
       input->og = NULL;
     }
   }
