@@ -36,18 +36,20 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "oggz_macros.h"
+
 /* #define DEBUG */
 
 #define TOOLNAME_LEN 32
 
 int
-usage (char * progname)
+usage (char * UNUSED(progname))
 {
   printf ("Usage: oggz <subcommand> [options] filename ...\n\n");
 
   printf ("oggz is a commandline tool for manipulating Ogg files. It supports\n"
           "multiplexed files conformant with RFC3533. Oggz can parse headers for\n"
-          "CELT, CMML, FLAC, Kate, PCM, Speex, Theora and Vorbis, and can read and write\n"
+          "CELT, CMML, FLAC, Kate, Opus, PCM, Speex, Theora, Vorbis and VP8, and can read and write\n"
           "Ogg Skeleton logical bitstreams.\n");
 
   printf ("\nCommands:\n");
