@@ -40,6 +40,7 @@
 #include "oggz/oggz.h"
 
 #include "dirac.h"
+#include "oggz_byteorder.h"
 #include "oggz_tools_dirac.h"
 
 #include "oggz_tools_vp8.h"
@@ -56,77 +57,6 @@
 #  define PRId64 "I64d"
 #endif
 
-
-static  ogg_uint32_t
-_le_32 (ogg_uint32_t i)
-{
-   ogg_uint32_t ret=i;
-#ifdef WORDS_BIGENDIAN
-   ret =  (i>>24);
-   ret += (i>>8) & 0x0000ff00;
-   ret += (i<<8) & 0x00ff0000;
-   ret += (i<<24);
-#endif
-   return ret;
-}
-
-static  ogg_uint16_t
-_be_16 (ogg_uint16_t s)
-{
-  unsigned short ret=s;
-#ifndef WORDS_BIGENDIAN
-  ret = (s>>8) & 0x00ffU;
-  ret += (s<<8) & 0xff00U;
-#endif
-  return ret;
-}
-
-static  ogg_uint32_t
-_be_32 (ogg_uint32_t i)
-{
-   ogg_uint32_t ret=i;
-#ifndef WORDS_BIGENDIAN
-   ret =  (i>>24);
-   ret += (i>>8) & 0x0000ff00;
-   ret += (i<<8) & 0x00ff0000;
-   ret += (i<<24);
-#endif
-   return ret;
-}
-
-static  ogg_int64_t
-_le_64 (ogg_int64_t l)
-{
-  ogg_int64_t ret=l;
-  unsigned char *ucptr = (unsigned char *)&ret;
-#ifdef WORDS_BIGENDIAN
-  unsigned char temp;
-
-  temp = ucptr [0] ;
-  ucptr [0] = ucptr [7] ;
-  ucptr [7] = temp ;
-
-  temp = ucptr [1] ;
-  ucptr [1] = ucptr [6] ;
-  ucptr [6] = temp ;
-
-  temp = ucptr [2] ;
-  ucptr [2] = ucptr [5] ;
-  ucptr [5] = temp ;
-
-  temp = ucptr [3] ;
-  ucptr [3] = ucptr [4] ;
-  ucptr [4] = temp ;
-
-#endif
-  return (*(ogg_int64_t *)ucptr);
-}
-
-#define INT32_LE_AT(x) _le_32((*(ogg_int32_t *)(x)))
-#define INT16_BE_AT(x) _be_16((*(ogg_uint16_t *)(x)))
-#define INT32_BE_AT(x) _be_32((*(ogg_int32_t *)(x)))
-#define INT64_LE_AT(x) _le_64((*(ogg_int64_t *)(x)))
-
 typedef char * (* OTCodecInfoFunc) (unsigned char * data, long n);
 
 static char *
@@ -139,15 +69,15 @@ ot_theora_info (unsigned char * data, long len)
 
   buf = malloc (128);
 
-  width = INT16_BE_AT(&data[15]);
-  height = INT16_BE_AT(&data[18]);
+  width = int16_be_at(&data[15]);
+  height = int16_be_at(&data[18]);
 
   snprintf (buf, 128,
             "\tTheora-Version: %d.%d.%d\n"
 	    "\tVideo-Framerate: %.3f fps\n"
 	    "\tVideo-Width: %d\n\tVideo-Height: %d\n",
             data[7], data[8], data[9],
-	    (double)INT32_BE_AT(&data[22])/ (double)INT32_BE_AT(&data[26]),
+	    (double)int32_be_at(&data[22])/ (double)int32_be_at(&data[26]),
 	    width, height);
 
   return buf;
@@ -164,7 +94,7 @@ ot_vorbis_info (unsigned char * data, long len)
 
   snprintf (buf, 60,
 	    "\tAudio-Samplerate: %d Hz\n\tAudio-Channels: %d\n",
-	    INT32_LE_AT(&data[12]), (int)(data[11]));
+	    int32_le_at(&data[12]), (int)(data[11]));
 
   return buf;
 }
@@ -180,7 +110,7 @@ ot_speex_info (unsigned char * data, long len)
 
   snprintf (buf, 60,
 	    "\tAudio-Samplerate: %d Hz\n\tAudio-Channels: %d\n",
-	    INT32_LE_AT(&data[36]), INT32_LE_AT(&data[48]));
+	    int32_le_at(&data[36]), int32_le_at(&data[48]));
 
   return buf;
 }
@@ -196,7 +126,7 @@ ot_celt_info (unsigned char * data, long len)
 
   snprintf (buf, 60,
 	    "\tAudio-Samplerate: %d Hz\n\tAudio-Channels: %d\n",
-	    INT32_LE_AT(&data[40]), INT32_LE_AT(&data[44]));
+	    int32_le_at(&data[40]), int32_le_at(&data[44]));
 
   return buf;
 }
@@ -243,7 +173,7 @@ ot_oggpcm2_info (unsigned char * data, long len)
 
   snprintf (buf, 60,
 	    "\tAudio-Samplerate: %d Hz\n\tAudio-Channels: %d\n",
-	    INT32_BE_AT(&data[16]), (int)data[21]);
+	    int32_be_at(&data[16]), (int)data[21]);
 
   return buf;
 }
@@ -310,8 +240,8 @@ ot_vp8_info (unsigned char * data, long len)
 	    "\tVideo-Framerate: %.3f fps\n"
 	    "\tVideo-Width: %d\n\tVideo-Height: %d\n",
             data[6], data[7],
-	    (double)INT32_BE_AT(&data[18])/ (double)INT32_BE_AT(&data[22]),
-	    INT16_BE_AT(&data[8]), INT16_BE_AT(&data[10]));
+	    (double)int32_be_at(&data[18])/ (double)int32_be_at(&data[22]),
+	    int16_be_at(&data[8]), int16_be_at(&data[10]));
 
   return buf;
 }
@@ -357,16 +287,16 @@ ot_skeleton_info (unsigned char * data, long len)
 
   buf = malloc (60);
 
-  pres_n = (double)INT64_LE_AT(&data[12]);
-  pres_d = (double)INT64_LE_AT(&data[20]);
+  pres_n = (double)int64_le_at(&data[12]);
+  pres_d = (double)int64_le_at(&data[20]);
   if (pres_d != 0.0) {
     pres = pres_n / pres_d;
   } else {
     pres = 0.0;
   }
 
-  base_n = (double)INT64_LE_AT(&data[28]);
-  base_d = (double)INT64_LE_AT(&data[36]);
+  base_n = (double)int64_le_at(&data[28]);
+  base_d = (double)int64_le_at(&data[36]);
   if (base_d != 0.0) {
     base = base_n / base_d;
   } else {
