@@ -19,6 +19,7 @@
 
 #include <ogg/ogg.h>
 
+#include "oggz_byteorder.h"
 #include "oggz_macros.h"
 
 #include "skeleton.h"
@@ -27,58 +28,6 @@
 #define snprintf _snprintf
 #endif 
 
-static  unsigned short
-_le_16 (unsigned short s)
-{
-  unsigned short ret=s;
-#ifdef WORDS_BIGENDIAN
-  ret = (s>>8) & 0x00ffU;
-  ret += (s<<8) & 0xff00U;
-#endif
-  return ret;
-}
-
-static  ogg_uint32_t
-_le_32 (ogg_uint32_t i)
-{
-   ogg_uint32_t ret=i;
-#ifdef WORDS_BIGENDIAN
-   ret =  (i>>24);
-   ret += (i>>8) & 0x0000ff00;
-   ret += (i<<8) & 0x00ff0000;
-   ret += (i<<24);
-#endif
-   return ret;
-}
-
-static  ogg_int64_t
-_le_64 (ogg_int64_t l)
-{
-  ogg_int64_t ret=l;
-  unsigned char *ucptr = (unsigned char *)&ret;
-#ifdef WORDS_BIGENDIAN
-  unsigned char temp;
-
-  temp = ucptr [0] ;
-  ucptr [0] = ucptr [7] ;
-  ucptr [7] = temp ;
-
-  temp = ucptr [1] ;
-  ucptr [1] = ucptr [6] ;
-  ucptr [6] = temp ;
-
-  temp = ucptr [2] ;
-  ucptr [2] = ucptr [5] ;
-  ucptr [5] = temp ;
-
-  temp = ucptr [3] ;
-  ucptr [3] = ucptr [4] ;
-  ucptr [4] = temp ;
-
-#endif
-  return (*(ogg_int64_t *)ucptr);
-}
-
 /* write an ogg_page to a file pointer */
 int write_ogg_page_to_file(ogg_page *og, FILE *out) {
    int written;
@@ -124,12 +73,12 @@ int ogg_from_fishead(fishead_packet *fp,ogg_packet *op) {
     memset(op->packet, 0, FISHEAD_SIZE);
 
     memcpy (op->packet, FISHEAD_IDENTIFIER, 8); /* identifier */
-    *((ogg_uint16_t*)(op->packet+8)) = _le_16 (SKELETON_VERSION_MAJOR); /* version major */
-    *((ogg_uint16_t*)(op->packet+10)) = _le_16 (SKELETON_VERSION_MINOR); /* version minor */
-    *((ogg_int64_t*)(op->packet+12)) = _le_64 (fp->ptime_n); /* presentationtime numerator */
-    *((ogg_int64_t*)(op->packet+20)) = _le_64 (fp->ptime_d); /* presentationtime denominator */
-    *((ogg_int64_t*)(op->packet+28)) = _le_64 (fp->btime_n); /* basetime numerator */
-    *((ogg_int64_t*)(op->packet+36)) = _le_64 (fp->btime_d); /* basetime denominator */
+    *((ogg_uint16_t*)(op->packet+8)) = le_16_ (SKELETON_VERSION_MAJOR); /* version major */
+    *((ogg_uint16_t*)(op->packet+10)) = le_16_ (SKELETON_VERSION_MINOR); /* version minor */
+    *((ogg_int64_t*)(op->packet+12)) = le_64_ (fp->ptime_n); /* presentationtime numerator */
+    *((ogg_int64_t*)(op->packet+20)) = le_64_ (fp->ptime_d); /* presentationtime denominator */
+    *((ogg_int64_t*)(op->packet+28)) = le_64_ (fp->btime_n); /* basetime numerator */
+    *((ogg_int64_t*)(op->packet+36)) = le_64_ (fp->btime_d); /* basetime denominator */
     /* TODO: UTC time, set to zero for now */
 
     op->b_o_s = 1;   /* its the first packet of the stream */
@@ -157,13 +106,13 @@ int ogg_from_fisbone(fisbone_packet *fp,ogg_packet *op) {
 
     memset (op->packet, 0, packet_size);
     memcpy (op->packet, FISBONE_IDENTIFIER, 8); /* identifier */
-    *((ogg_uint32_t*)(op->packet+8)) = _le_32 (FISBONE_MESSAGE_HEADER_OFFSET); /* offset of the message header fields */
-    *((ogg_uint32_t*)(op->packet+12)) = _le_32 (fp->serial_no); /* serialno of the respective stream */
-    *((ogg_uint32_t*)(op->packet+16)) = _le_32 (fp->nr_header_packet); /* number of header packets */
-    *((ogg_int64_t*)(op->packet+20)) = _le_64 (fp->granule_rate_n); /* granulrate numerator */
-    *((ogg_int64_t*)(op->packet+28)) = _le_64 (fp->granule_rate_d); /* granulrate denominator */
-    *((ogg_int64_t*)(op->packet+36)) = _le_64 (fp->start_granule); /* start granule */
-    *((ogg_uint32_t*)(op->packet+44)) = _le_32 (fp->preroll); /* preroll, for theora its 0 */
+    *((ogg_uint32_t*)(op->packet+8)) = le_32_ (FISBONE_MESSAGE_HEADER_OFFSET); /* offset of the message header fields */
+    *((ogg_uint32_t*)(op->packet+12)) = le_32_ (fp->serial_no); /* serialno of the respective stream */
+    *((ogg_uint32_t*)(op->packet+16)) = le_32_ (fp->nr_header_packet); /* number of header packets */
+    *((ogg_int64_t*)(op->packet+20)) = le_64_ (fp->granule_rate_n); /* granulrate numerator */
+    *((ogg_int64_t*)(op->packet+28)) = le_64_ (fp->granule_rate_d); /* granulrate denominator */
+    *((ogg_int64_t*)(op->packet+36)) = le_64_ (fp->start_granule); /* start granule */
+    *((ogg_uint32_t*)(op->packet+44)) = le_32_ (fp->preroll); /* preroll, for theora its 0 */
     *(op->packet+48) = fp->granule_shift; /* granule shift */
     if (fp->message_header_fields)
       memcpy((op->packet+FISBONE_SIZE), fp->message_header_fields, fp->current_header_size);
@@ -183,12 +132,12 @@ static int fishead_from_data (const unsigned char * data, int UNUSED(len), fishe
     if (memcmp(data, FISHEAD_IDENTIFIER, 8))
       return -1;
 
-    fp->version_major = _le_16 (*((ogg_uint16_t*)(data+8))); /* version major */
-    fp->version_minor = _le_16 (*((ogg_uint16_t*)(data+10))); /* version minor */
-    fp->ptime_n = _le_64 (*((ogg_int64_t*)(data+12))); /* presentationtime numerator */
-    fp->ptime_d = _le_64 (*((ogg_int64_t*)(data+20))); /* presentationtime denominator */
-    fp->btime_n = _le_64 (*((ogg_int64_t*)(data+28))); /* basetime numerator */
-    fp->btime_d = _le_64 (*((ogg_int64_t*)(data+36))); /* basetime denominator */
+    fp->version_major = le_16_ (*((ogg_uint16_t*)(data+8))); /* version major */
+    fp->version_minor = le_16_ (*((ogg_uint16_t*)(data+10))); /* version minor */
+    fp->ptime_n = le_64_ (*((ogg_int64_t*)(data+12))); /* presentationtime numerator */
+    fp->ptime_d = le_64_ (*((ogg_int64_t*)(data+20))); /* presentationtime denominator */
+    fp->btime_n = le_64_ (*((ogg_int64_t*)(data+28))); /* basetime numerator */
+    fp->btime_d = le_64_ (*((ogg_int64_t*)(data+36))); /* basetime denominator */
     memcpy(fp->UTC, data+44, 20);
 
     return 0;
@@ -212,12 +161,12 @@ static int fisbone_from_data (const unsigned char * data, int len, fisbone_packe
     if (memcmp(data, FISBONE_IDENTIFIER, 8))
 	  return -1;
 
-    fp->serial_no = _le_32 (*((ogg_uint32_t*)(data+12))); /* serialno of the stream represented by this fisbone packet */
-    fp->nr_header_packet = _le_32 (*((ogg_uint32_t*)(data+16))); /* number of header packets */
-    fp->granule_rate_n = _le_64 (*((ogg_int64_t*)(data+20))); /* granulrate numerator */
-    fp->granule_rate_d = _le_64 (*((ogg_int64_t*)(data+28))); /* granulrate denominator */
-    fp->start_granule = _le_64 (*((ogg_int64_t*)(data+36))); /* start granule */
-    fp->preroll = _le_32 (*((ogg_uint32_t*)(data+44))); /* preroll, for theora its 0 */
+    fp->serial_no = le_32_ (*((ogg_uint32_t*)(data+12))); /* serialno of the stream represented by this fisbone packet */
+    fp->nr_header_packet = le_32_ (*((ogg_uint32_t*)(data+16))); /* number of header packets */
+    fp->granule_rate_n = le_64_ (*((ogg_int64_t*)(data+20))); /* granulrate numerator */
+    fp->granule_rate_d = le_64_ (*((ogg_int64_t*)(data+28))); /* granulrate denominator */
+    fp->start_granule = le_64_ (*((ogg_int64_t*)(data+36))); /* start granule */
+    fp->preroll = le_32_ (*((ogg_uint32_t*)(data+44))); /* preroll, for theora its 0 */
     fp->granule_shift = *(data+48); /* granule shift */
     fp->current_header_size = len - FISBONE_SIZE;
     fp->message_header_fields = _ogg_calloc(fp->current_header_size+1, sizeof(char));
